#! /usr/bin/env python
# -*- coding: utf8 -*-
#
# Copyright (c) 2009, Nokia Corp.
# All rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in the
#       documentation and/or other materials provided with the distribution.
#     * Neither the name of Nokia nor the names of its contributors may be
#       used to endorse or promote products derived from this software without
#       specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED THE COPYRIGHT HOLDERS AND CONTRIBUTORS ''AS IS''
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED. IN NO EVENT SHALL COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
# SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
# CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

__author__ = 'eemeli.kantola@iki.fi (Eemeli Kantola)'

import unittest
import doctest

import kpwrapper
kpwrapper.debug = True

from kpwrapper import Triple, TransactionWrapper

class TestModule(unittest.TestCase):
    def test_doc(self):
        doctest.testmod(kpwrapper)

class TestTriple(unittest.TestCase):
    def test_equals(self):
        self.assertEquals(Triple('a', 'b', 'c'), Triple('a', 'b', 'c'))

class TestTransactionWrapper(unittest.TestCase):
    def setUp(self):
        self.tw = TransactionWrapper('node',
                                     lambda node, handle: (node, handle),
                                     lambda node, tx: None,
                                     'handle')
    
    def test_open(self):
        self.tw.open()
        self.assertEquals(('node', 'handle'), self.tw.tx)
        
    def test_close(self):
        self.tw.tx = 'tx'
        self.tw.close()
        self.assertEquals(None, self.tw.tx)

if __name__ == "__main__":
    #import sys;sys.argv = ['', 'Test.testName']
    unittest.main()
